pub enum CacheAgeStatus {
Fresh,
Stale,
Unmanaged,
Unknown,
}Expand description
CacheAgeStatus
Caller-relative age classification for one complete cache file.
Variants
Fresh
The cache is within its registered family stale threshold.
Stale
The cache is older than its registered family stale threshold.
Unmanaged
The cache has a readable age but no registered family stale threshold.
Unknown
The cache age cannot be calculated from its generic timestamp evidence.
Implementations