pub type CloudEngineNodeRow = IcNodeStatusRow;Expand description
CloudEngineNodeRow
Raw official Dashboard node observation selected by the Type4 reward-type scope.
Aliased Type
pub struct CloudEngineNodeRow {Show 19 fields
pub node_id: String,
pub node_operator_id: String,
pub node_provider_id: String,
pub node_provider_name: String,
pub node_type: String,
pub node_reward_type: String,
pub status: String,
pub alert_name: Option<String>,
pub subnet_id: Option<String>,
pub cloud_engine_subnet_id: Option<String>,
pub data_center_id: String,
pub data_center_name: String,
pub owner: String,
pub region: String,
pub guestos_version: Option<String>,
pub guestos_tee_active: Option<bool>,
pub ip_address: Option<String>,
pub ipv4_connectivity_status: Option<bool>,
pub node_hardware_generation: Option<String>,
}Fields
node_id: StringCanonical node principal.
node_operator_id: StringCanonical node-operator principal.
node_provider_id: StringCanonical node-provider principal.
node_provider_name: StringOff-chain Dashboard node-provider name.
node_type: StringRaw Dashboard node type.
node_reward_type: StringRaw Registry reward type reported by the Dashboard.
status: StringRaw Dashboard operational status.
alert_name: Option<String>Raw Dashboard alert name when present.
subnet_id: Option<String>Assigned Subnet principal when present.
cloud_engine_subnet_id: Option<String>CloudEngine Subnet principal when reported by the selected Dashboard scope.
data_center_id: StringDashboard data-center identifier.
data_center_name: StringDashboard data-center name.
owner: StringDashboard infrastructure owner label.
region: StringRaw Dashboard geographic region label.
guestos_version: Option<String>Observed GuestOS version when reported.
guestos_tee_active: Option<bool>Observed GuestOS trusted-execution status when reported.
ip_address: Option<String>Observed node IP address when reported.
ipv4_connectivity_status: Option<bool>Observed IPv4-connectivity state when reported.
node_hardware_generation: Option<String>Dashboard hardware-generation label when reported.