IcMetricKind

Enum IcMetricKind 

pub enum IcMetricKind {
    InstructionRate,
    MessageExecutionRate,
    CycleBurnRate,
    BlockRate,
    IcNodeCount,
    IcSubnetTotal,
    RegisteredCanistersCount,
    TotalIcEnergyConsumptionRateKwh,
    BoundaryNodesCount,
}
IcMetricKind

One bounded network metric exposed by the official Dashboard Metrics API.

Variants



InstructionRate

Network instruction execution rate.



MessageExecutionRate

Network message execution rate.



CycleBurnRate

Network cycle burn rate.



BlockRate

Network block ingestion rate.



IcNodeCount

Total and currently up node counts.



IcSubnetTotal

Total Subnet count.



RegisteredCanistersCount

Running and stopped canister counts.



TotalIcEnergyConsumptionRateKwh

Total estimated IC energy-consumption rate in kWh.



BoundaryNodesCount

Active boundary-node count.

Implementations

Source

impl IcMetricKind

pub const fn all() -> [Self; 9]

Return every metric supported by the bounded report adapter.

pub const fn as_str(self) -> &'static str

Return the official Dashboard Metrics API path name.