IcIcrcHolderListQuery

Struct IcIcrcHolderListQuery 

pub struct IcIcrcHolderListQuery {
    pub after: Option<String>,
    pub before: Option<String>,
    pub limit: u16,
    pub sort_by: IcIcrcHolderSort,
}
IcIcrcHolderListQuery

One explicitly bounded holder-index page query.

Fields

after: Option<String>

Opaque exclusive forward cursor returned by an earlier page.

before: Option<String>

Opaque exclusive backward cursor returned by an earlier page.

limit: u16

Maximum rows requested from the official API.

sort_by: IcIcrcHolderSort

Stable upstream sort order applied to the page.

Implementations

Source

impl IcIcrcHolderListQuery

pub const fn new(limit: u16, sort_by: IcIcrcHolderSort) -> Self

Construct one holder-index page query.

pub fn with_after(self, after: impl Into<String>) -> Self

Continue after one opaque cursor.

pub fn with_before(self, before: impl Into<String>) -> Self

Continue before one opaque cursor.