pub struct IcNodeStatusObservation {
pub source: IcDashboardReportProvenance,
pub scope: IcNodeStatusScope,
pub cloud_engine_nodes_included: bool,
pub cache: Option<IcNodeStatusCacheEvidence>,
}Expand description
IcNodeStatusObservation
Shared source, scope, and optional cache evidence for status reports.
Fields
source: IcDashboardReportProvenanceOfficial Dashboard source provenance.
scope: IcNodeStatusScopeExplicit node collection scope.
cloud_engine_nodes_included: boolWhether cloud-engine nodes were included in the source collection.
cache: Option<IcNodeStatusCacheEvidence>Local cache evidence, absent for a pure live snapshot.