pub struct IcrcArchiveFollowErrorRow {
pub callback_canister_id: String,
pub callback_method: String,
pub ranges: Vec<IcrcArchivedRangeRow>,
pub error: String,
}Expand description
IcrcArchiveFollowErrorRow
Serializable row for one archive callback that could not be followed.
Fields
callback_canister_id: Stringcallback_method: Stringranges: Vec<IcrcArchivedRangeRow>error: StringTrait Implementations
Sourceimpl Clone for IcrcArchiveFollowErrorRow
impl Clone for IcrcArchiveFollowErrorRow
Sourcefn clone(&self) -> IcrcArchiveFollowErrorRow
fn clone(&self) -> IcrcArchiveFollowErrorRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IcrcArchiveFollowErrorRow
impl Debug for IcrcArchiveFollowErrorRow
impl Eq for IcrcArchiveFollowErrorRow
Sourceimpl PartialEq for IcrcArchiveFollowErrorRow
impl PartialEq for IcrcArchiveFollowErrorRow
Sourcefn eq(&self, other: &IcrcArchiveFollowErrorRow) -> bool
fn eq(&self, other: &IcrcArchiveFollowErrorRow) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IcrcArchiveFollowErrorRow