NnsGovernanceError

Enum NnsGovernanceError 

pub enum NnsGovernanceError {
    UnsupportedNetwork {
        network: String,
    },
    InvalidSourceSelection {
        reason: String,
    },
    SourceEvidenceMismatch {
        reason: String,
    },
    AgentBuild {
        endpoint: String,
        reason: String,
    },
    AgentCall {
        method: &'static str,
        reason: String,
    },
    InterCanisterCall {
        method: &'static str,
        reason: String,
    },
    InterCanisterCallRejected {
        method: &'static str,
        reject_code: u32,
        message: String,
    },
    CandidEncode {
        message: &'static str,
        reason: String,
    },
    CandidDecode {
        message: &'static str,
        reason: String,
    },
    ResponseTooLarge {
        method: &'static str,
        actual_bytes: usize,
        maximum_bytes: usize,
    },
    Governance {
        error_type: i32,
        message: String,
    },
    InvalidMetrics {
        field: &'static str,
        key: u64,
        value: f64,
    },
}
NnsGovernanceError

Portable failure returned while collecting or assembling a Governance report.

Variants



UnsupportedNetwork

The requested network is not the supported mainnet identity.

Fields

network: String

Rejected network identity.



InvalidSourceSelection

The selected transport cannot be executed by the source adapter.

Fields

reason: String

Validation failure.



SourceEvidenceMismatch

Returned provenance did not match the requested transport.

Fields

reason: String

Evidence mismatch.



AgentBuild

Native IC agent setup failed.

Fields

endpoint: String

Endpoint used to build the agent.

reason: String

Agent construction failure.



AgentCall

A native IC agent query failed.

Fields

method: &'static str

Governance method being queried.

reason: String

Query failure.



InterCanisterCall

A replicated inter-canister call could not be submitted.

Fields

method: &'static str

Governance method being called.

reason: String

Cycle-balance or call-perform failure.



InterCanisterCallRejected

A replicated inter-canister call returned an IC reject.

Fields

method: &'static str

Governance method being called.

reject_code: u32

Raw IC reject code.

message: String

Reject message returned by the IC.



CandidEncode

A Candid request could not be encoded.

Fields

message: &'static str

Candid request type.

reason: String

Encoding failure.



CandidDecode

A Candid response could not be decoded.

Fields

message: &'static str

Candid response type.

reason: String

Decoding failure.



ResponseTooLarge

A response exceeded the library’s explicit raw-response byte bound.

Fields

method: &'static str

Governance method being decoded.

actual_bytes: usize

Actual response size.

maximum_bytes: usize

Maximum accepted response size.



Governance

Governance returned its typed application-level error.

Fields

error_type: i32

Raw Governance error type.

message: String

Governance error message.



InvalidMetrics

Governance returned a non-finite metric that JSON cannot preserve.

Fields

field: &'static str

Native Governance metric field.

key: u64

Raw metric bucket key.

value: f64

Rejected non-finite bucket value.