NnsNeuronType

Enum NnsNeuronType 

pub enum NnsNeuronType {
    Unknown,
    Unspecified,
    Seed,
    Ect,
    UnknownCode(i32),
}
NnsNeuronType

Native optional NNS Governance neuron type with unknown evidence retained.

Variants



Unknown

Governance omitted the optional neuron-type code.



Unspecified

Governance supplied the unspecified neuron-type code.



Seed

Seed neuron.



Ect

Early-contributor-token neuron.



UnknownCode(i32)

Governance supplied an unrecognized native code.

Implementations

Source

impl NnsNeuronType

pub const fn from_code(code: Option<i32>) -> Self

Classify one optional raw native code without discarding unknown evidence.

pub const fn code(self) -> Option<i32>

Return the exact optional native code represented by this classification.