NnsNeuronVisibility

Enum NnsNeuronVisibility 

pub enum NnsNeuronVisibility {
    Unknown,
    Unspecified,
    Private,
    Public,
    UnknownCode(i32),
}
NnsNeuronVisibility

Native optional NNS Governance neuron visibility with unknown evidence retained.

Variants



Unknown

Governance omitted the optional visibility code.



Unspecified

Governance supplied the unspecified visibility code.



Private

Neuron is private.



Public

Neuron is public.



UnknownCode(i32)

Governance supplied an unrecognized native code.

Implementations

Source

impl NnsNeuronVisibility

pub const fn from_code(code: Option<i32>) -> Self

Classify one optional raw native code without discarding unknown evidence.

pub const fn code(self) -> Option<i32>

Return the exact optional native code represented by this classification.