pub struct NnsNeuronCollectionStep {
pub page: NnsNeuronListReport,
pub state: NnsNeuronCollectionState,
}Expand description
NnsNeuronCollectionStep
One admitted bounded page and the continuation state that follows it.
Fields
page: NnsNeuronListReportPage returned by the shared public-neuron report builder.
state: NnsNeuronCollectionStateValidated state to persist only after retaining the page.