pub struct NnsNeuronInfoReport {
pub context: NnsGovernanceReportContext,
pub cache_path: Option<String>,
pub from_cache: bool,
pub verbose: bool,
pub neuron: NnsNeuronRow,
}Expand description
NnsNeuronInfoReport
Serializable public view of one NNS neuron.
Fields
context: NnsGovernanceReportContextShared Governance authority and transport provenance.
cache_path: Option<String>Cache path when the row came from a complete snapshot.
from_cache: boolWhether the row came from a complete local snapshot.
verbose: boolWhether verbose text rendering was requested.
neuron: NnsNeuronRowPublic Governance neuron view.