pub struct NnsNeuronStateDistribution {
pub state: i32,
pub state_text: NnsNeuronState,
pub neuron_count: u64,
pub effective_stake_e8s: u64,
}Expand description
NnsNeuronStateDistribution
Public neuron count and effective stake for one raw Governance state code.
Fields
state: i32Raw native Governance state code.
state_text: NnsNeuronStateClassification derived from the raw state code.
neuron_count: u64Number of collected neurons with this state code.
effective_stake_e8s: u64Sum of public effective stake for neurons with this state code.