pub struct NnsNeuronTypeDistribution {
pub neuron_type: Option<i32>,
pub neuron_type_text: NnsNeuronType,
pub neuron_count: u64,
pub effective_stake_e8s: u64,
}Expand description
NnsNeuronTypeDistribution
Public neuron count and effective stake for one optional Governance neuron-type code.
Fields
neuron_type: Option<i32>Raw optional native Governance neuron-type code.
neuron_type_text: NnsNeuronTypeClassification derived from the raw optional neuron-type code.
neuron_count: u64Number of collected neurons with this type code or absence.
effective_stake_e8s: u64Sum of public effective stake for neurons with this type code or absence.