pub struct NnsProposalCollectionStep {
pub page: NnsProposalListReport,
pub state: NnsProposalCollectionState,
}Expand description
NnsProposalCollectionStep
One admitted bounded page and the continuation state that follows it.
Fields
page: NnsProposalListReportUnfiltered page returned by the shared proposal report builder.
state: NnsProposalCollectionStateValidated state to persist only after retaining the page.