SnsProposalTopicFilter

Enum SnsProposalTopicFilter 

pub enum SnsProposalTopicFilter {
    Any,
    DaoCommunitySettings,
    SnsFrameworkManagement,
    DappCanisterManagement,
    ApplicationBusinessLogic,
    Governance,
    TreasuryAssetManagement,
    CriticalDappOperations,
}
SnsProposalTopicFilter

Report-model topic filter for bounded SNS proposal listings.

Variants



Any



DaoCommunitySettings



SnsFrameworkManagement



DappCanisterManagement



ApplicationBusinessLogic



Governance



TreasuryAssetManagement



CriticalDappOperations

Implementations

Source

impl SnsProposalTopicFilter

pub const fn as_str(self) -> &'static str

Return the stable label used in text and JSON reports.

pub const fn topic_label(self) -> Option<&'static str>

Return the row topic label for concrete topic filters.