pub enum SnsRewardAllocationStatus {
Valid,
NoAllocation,
Invalid,
}Expand description
SnsRewardAllocationStatus
Reconciliation outcome for one pair of SNS reward checkpoints.
Variants
Valid
Every invariant reconciled to one positive native reward distribution.
NoAllocation
Every invariant reconciled to a native distribution of zero.
Invalid
At least one checkpoint, continuity, policy, or reconciliation invariant failed.
Implementations