pub struct SnsCanisterGap {
pub kind: SnsCanisterGapKind,
pub role: SnsCanisterRole,
pub inventory_canister_id: Option<String>,
pub summary_canister_id: Option<String>,
}Expand description
SnsCanisterGap
One explicit inventory or health relation gap returned by SNS Root.
Fields
kind: SnsCanisterGapKindTyped gap classification.
role: SnsCanisterRoleNative SNS canister role involved in the gap.
inventory_canister_id: Option<String>Canister id supplied by the inventory response, when available.
summary_canister_id: Option<String>Canister id supplied by the health summary, when available.