SnsCanisterRow

Struct SnsCanisterRow 

pub struct SnsCanisterRow {
    pub role: SnsCanisterRole,
    pub canister_id: String,
    pub status: Option<SnsCanisterStatus>,
    pub module_hash_hex: Option<String>,
    pub cycles: Option<String>,
    pub memory_size: Option<String>,
    pub idle_cycles_burned_per_day: Option<String>,
    pub controllers: Vec<String>,
}
SnsCanisterRow

One canister in the authoritative SNS Root inventory.

Fields

role: SnsCanisterRole

Native SNS canister role.

canister_id: String

Canonical canister principal text.

status: Option<SnsCanisterStatus>

Native canister running state when Root returned health evidence.

module_hash_hex: Option<String>

Running Wasm module hash as lowercase hexadecimal text.

cycles: Option<String>

Raw cycle balance as unsigned decimal text.

memory_size: Option<String>

Raw memory size in bytes as unsigned decimal text.

idle_cycles_burned_per_day: Option<String>

Raw idle cycles burned per day as unsigned decimal text.

controllers: Vec<String>

Canonical controller principals returned by Root.