pub struct SnsMaturityDisbursementRow {
pub timestamp_of_disbursement_seconds: u64,
pub amount_e8s: u64,
pub account_to_disburse_to: Option<SnsNeuronAccount>,
pub finalize_disbursement_timestamp_seconds: Option<u64>,
}Expand description
SnsMaturityDisbursementRow
Native maturity disbursement that Governance has not yet finalized.
Fields
timestamp_of_disbursement_seconds: u64Unix timestamp at which the maturity disbursement was scheduled.
amount_e8s: u64Raw scheduled amount in e8s.
account_to_disburse_to: Option<SnsNeuronAccount>Complete optional destination account returned by Governance.
finalize_disbursement_timestamp_seconds: Option<u64>Unix timestamp at which Governance expects to finalize the disbursement.