pub struct SnsNeuronAccount {
pub owner: Option<String>,
pub subaccount_hex: Option<String>,
}Expand description
SnsNeuronAccount
Native optional destination account retained for a pending maturity disbursement.
Fields
owner: Option<String>Canonical destination owner when Governance supplied one.
subaccount_hex: Option<String>Native destination subaccount encoded as lowercase hexadecimal when supplied.