pub struct SnsNeuronPermissionValue {
pub code: i32,
pub name: String,
}Expand description
SnsNeuronPermissionValue
Raw SNS Governance permission code with its current native label.
Fields
code: i32Raw integer permission code returned by Governance.
name: StringCurrent native permission label, or unknown for an unrecognized code.
Implementations