pub struct SnsSwapDerivedState {
pub sns_tokens_per_icp: Option<f64>,
pub buyer_total_icp_e8s: Option<u64>,
pub direct_participation_icp_e8s: Option<u64>,
pub neurons_fund_participation_icp_e8s: Option<u64>,
pub direct_participant_count: Option<u64>,
pub cf_participant_count: Option<u64>,
pub cf_neuron_count: Option<u64>,
}Expand description
SnsSwapDerivedState
Native aggregate participation values returned by the swap canister.
Fields
sns_tokens_per_icp: Option<f64>Derived SNS-token amount per ICP, when returned.
buyer_total_icp_e8s: Option<u64>Total buyer ICP in e8s, when returned.
direct_participation_icp_e8s: Option<u64>Direct-participation ICP in e8s, when returned.
neurons_fund_participation_icp_e8s: Option<u64>Neurons’ Fund participation ICP in e8s, when returned.
direct_participant_count: Option<u64>Number of direct participants, when returned.
cf_participant_count: Option<u64>Number of Community Fund participants, when returned by older swap state.
cf_neuron_count: Option<u64>Number of Community Fund neurons, when returned by older swap state.