SnsSwapReport

Struct SnsSwapReport 

pub struct SnsSwapReport {
Show 21 fields pub schema_version: u32, pub network: String, pub sns_wasm_canister_id: String, pub fetched_at: String, pub source_endpoint: String, pub fetched_by: String, pub id: usize, pub name: String, pub root_canister_id: String, pub swap_canister_id: String, pub lifecycle_method: String, pub sale_parameters_method: String, pub derived_state_method: String, pub point_in_time_guaranteed: bool, pub component_query_count: usize, pub successful_component_query_count: usize, pub component_gap_count: usize, pub lifecycle: Option<SnsSwapLifecycle>, pub sale_parameters: Option<SnsSwapSaleParameters>, pub derived_state: Option<SnsSwapDerivedState>, pub gaps: Vec<SnsSwapQueryGap>,
}
SnsSwapReport

Bounded live report for one resolved SNS decentralization swap.

Fields

schema_version: u32

Report schema version.

network: String

Requested IC network identity.

sns_wasm_canister_id: String

Mainnet SNS-W canister used to resolve the SNS.

fetched_at: String

Collection timestamp in UTC.

source_endpoint: String

IC API endpoint used for SNS-W and swap calls.

fetched_by: String

Collector identity recorded by the source request.

id: usize

SNS-W list id assigned to this deployed SNS.

name: String

SNS name resolved during discovery.

root_canister_id: String

Root canister identity used to resolve this SNS.

swap_canister_id: String

Swap canister queried for lifecycle and sale state.

lifecycle_method: String

Native method used for lifecycle state.

sale_parameters_method: String

Native method used for sale parameters.

derived_state_method: String

Native method used for derived participation state.

point_in_time_guaranteed: bool

Whether all component values represent one authoritative point in time.

component_query_count: usize

Fixed number of bounded swap component queries attempted.

successful_component_query_count: usize

Number of component queries that returned successfully.

component_gap_count: usize

Number of typed component query gaps.

lifecycle: Option<SnsSwapLifecycle>

Lifecycle response, absent only when its query failed.

sale_parameters: Option<SnsSwapSaleParameters>

Sale parameters; None can also be a successful response with no configured parameters.

derived_state: Option<SnsSwapDerivedState>

Derived-state response, absent only when its query failed.

gaps: Vec<SnsSwapQueryGap>

Canonically ordered component query failures.