pub fn parse_catalog_json(data: &str) -> Result<RawSubnetCatalog, CatalogError>Expand description
Decode and structurally validate one untrusted raw subnet catalog JSON payload.
pub fn parse_catalog_json(data: &str) -> Result<RawSubnetCatalog, CatalogError>Decode and structurally validate one untrusted raw subnet catalog JSON payload.