pub struct SubnetCatalog {
pub catalog_schema_version: u32,
pub network: String,
pub registry_canister_id: String,
pub registry_version: u64,
pub fetched_at: String,
pub fetched_by: String,
pub source_endpoint: String,
pub resolver_backend: String,
pub subnets: Vec<SubnetInfo>,
pub routing_ranges: Vec<RoutingRange>,
}Expand description
SubnetCatalog
Fields
catalog_schema_version: u32network: Stringregistry_canister_id: Stringregistry_version: u64fetched_at: Stringfetched_by: Stringsource_endpoint: Stringresolver_backend: Stringsubnets: Vec<SubnetInfo>routing_ranges: Vec<RoutingRange>Implementations
Sourceimpl SubnetCatalog
impl SubnetCatalog
Sourcepub fn validate(&self) -> Result<(), CatalogError>
pub fn validate(&self) -> Result<(), CatalogError>
Validate schema, principal syntax, and routing references.
pub fn subnet_by_principal(&self, subnet_principal: &str) -> Option<&SubnetInfo>
pub fn routing_ranges_for_subnet( &self, subnet_principal: &str, ) -> Vec<&RoutingRange>
Sourceimpl SubnetCatalog
impl SubnetCatalog
Sourcepub fn resolve_principal(
&self,
input: &str,
forced: Option<ResolveAs>,
) -> Result<ResolvedSubnet, CatalogError>
pub fn resolve_principal( &self, input: &str, forced: Option<ResolveAs>, ) -> Result<ResolvedSubnet, CatalogError>
Resolve a principal as a known subnet or as a canister covered by a cached range.
Sourcepub fn resolve_principal_or_prefix(
&self,
input: &str,
forced: Option<ResolveAs>,
) -> Result<ResolvedSubnet, CatalogError>
pub fn resolve_principal_or_prefix( &self, input: &str, forced: Option<ResolveAs>, ) -> Result<ResolvedSubnet, CatalogError>
Resolve an exact principal or a unique cached subnet principal prefix.
Sourcepub fn resolve_principal_prefix(
&self,
input: &str,
forced: Option<ResolveAs>,
) -> Result<ResolvedSubnet, CatalogError>
pub fn resolve_principal_prefix( &self, input: &str, forced: Option<ResolveAs>, ) -> Result<ResolvedSubnet, CatalogError>
Resolve a unique prefix of a cached subnet principal.
Sourcepub fn resolve_canister(
&self,
input_principal: &str,
) -> Result<ResolvedSubnet, CatalogError>
pub fn resolve_canister( &self, input_principal: &str, ) -> Result<ResolvedSubnet, CatalogError>
Resolve a canister principal through cached routing ranges.