pub struct IcIcrcHolderListQuery {
pub after: Option<String>,
pub before: Option<String>,
pub limit: u16,
pub sort_by: IcIcrcHolderSort,
}Expand description
IcIcrcHolderListQuery
One explicitly bounded holder-index page query.
Fields
after: Option<String>Opaque exclusive forward cursor returned by an earlier page.
before: Option<String>Opaque exclusive backward cursor returned by an earlier page.
limit: u16Maximum rows requested from the official API.
sort_by: IcIcrcHolderSortStable upstream sort order applied to the page.
Implementations
Sourceimpl IcIcrcHolderListQuery
impl IcIcrcHolderListQuery
Sourcepub const fn new(limit: u16, sort_by: IcIcrcHolderSort) -> Self
pub const fn new(limit: u16, sort_by: IcIcrcHolderSort) -> Self
Construct one holder-index page query.
Sourcepub fn with_after(self, after: impl Into<String>) -> Self
pub fn with_after(self, after: impl Into<String>) -> Self
Continue after one opaque cursor.
Sourcepub fn with_before(self, before: impl Into<String>) -> Self
pub fn with_before(self, before: impl Into<String>) -> Self
Continue before one opaque cursor.