IcNodeStatusRow

Struct IcNodeStatusRow 

pub struct IcNodeStatusRow {
Show 19 fields pub node_id: String, pub node_operator_id: String, pub node_provider_id: String, pub node_provider_name: String, pub node_type: String, pub node_reward_type: String, pub status: String, pub alert_name: Option<String>, pub subnet_id: Option<String>, pub cloud_engine_subnet_id: Option<String>, pub data_center_id: String, pub data_center_name: String, pub owner: String, pub region: String, pub guestos_version: Option<String>, pub guestos_tee_active: Option<bool>, pub ip_address: Option<String>, pub ipv4_connectivity_status: Option<bool>, pub node_hardware_generation: Option<String>,
}
IcNodeStatusRow

One raw node observation retained from the official Dashboard node resource.

Fields

node_id: String

Canonical node principal.

node_operator_id: String

Canonical node-operator principal.

node_provider_id: String

Canonical node-provider principal.

node_provider_name: String

Off-chain Dashboard node-provider name.

node_type: String

Raw Dashboard node type.

node_reward_type: String

Raw Registry reward type reported by the Dashboard.

status: String

Raw Dashboard operational status.

alert_name: Option<String>

Raw Dashboard alert name when present.

subnet_id: Option<String>

Assigned Subnet principal when present.

cloud_engine_subnet_id: Option<String>

Cloud-engine Subnet principal when present in a future compatible scope.

data_center_id: String

Dashboard data-center identifier.

data_center_name: String

Dashboard data-center name.

owner: String

Dashboard infrastructure owner label.

region: String

Raw Dashboard geographic region label.

guestos_version: Option<String>

Observed GuestOS version when reported.

guestos_tee_active: Option<bool>

Observed GuestOS trusted-execution status when reported.

ip_address: Option<String>

Observed node IP address when reported.

ipv4_connectivity_status: Option<bool>

Observed IPv4-connectivity state when reported.

node_hardware_generation: Option<String>

Dashboard hardware-generation label when reported.

Implementations

Source

impl IcNodeStatusRow

pub fn operational_status(&self) -> IcNodeOperationalStatus

Return the known classification of this row’s raw status.

pub fn is_non_up(&self) -> bool

Return whether the raw row is anything other than known UP.