pub struct IcNodeStatusView {
pub target: Option<String>,
pub include_all: bool,
}Expand description
IcNodeStatusView
Target and attention selection shared by node, Subnet, and provider views.
Fields
target: Option<String>Optional exact identifier or unique principal prefix.
include_all: boolWhether fully-up rows or groups are included without a target.
Implementations
Sourceimpl IcNodeStatusView
impl IcNodeStatusView
Sourcepub fn with_target(self, target: impl Into<String>) -> Self
pub fn with_target(self, target: impl Into<String>) -> Self
Select one exact identifier or unique principal prefix.