pub enum IcrcAccountTransactionError {
Show 15 variants
InvalidSourceEndpoint {
value: String,
reason: String,
},
InvalidPageSize {
page_size: u32,
max_page_size: u32,
},
InvalidListLimit {
limit: u32,
},
InvalidMaxPages {
max_pages: u32,
},
InvalidCursor {
value: String,
reason: String,
},
Query(IcrcError),
IndexDiscovery {
ledger_canister_id: String,
source: IcrcError,
},
IndexUnavailable {
ledger_canister_id: String,
reason: String,
},
IndexLedgerMismatch {
index_canister_id: String,
expected_ledger_canister_id: String,
actual_ledger_canister_id: String,
},
IndexQuery {
index_canister_id: String,
message: String,
},
IncompleteCollection {
index_canister_id: Option<String>,
pages_fetched: u32,
rows_fetched: usize,
last_cursor: Option<String>,
reason: String,
},
CollectionPage {
index_canister_id: Option<String>,
pages_fetched: u32,
rows_fetched: usize,
last_cursor: Option<String>,
source: Box<Self>,
},
CollectionIndexMismatch {
expected_index_canister_id: String,
actual_index_canister_id: String,
},
InvalidCache {
path: PathBuf,
reason: String,
},
InvalidRefreshAttempt {
path: PathBuf,
reason: String,
},
}Expand description
IcrcAccountTransactionError
Error surfaced while resolving and querying an ICRC account index.
Variants
InvalidSourceEndpoint
A cache identity omitted its endpoint.
InvalidPageSize
A page or refresh requested an unsupported page size.
InvalidListLimit
A cache view requested no rows.
InvalidMaxPages
A diagnostic refresh bound cannot prove any collection progress.
InvalidCursor
A caller supplied a non-decimal or otherwise invalid candid Nat cursor.
Query(IcrcError)
A ledger, index, principal, Candid, or transport operation failed.
IndexDiscovery
ICRC-106 discovery could not be queried or decoded.
Fields
ICRC-106 discovery did not yield an index canister.
IndexLedgerMismatch
The selected index reports a different ledger identity.
Fields
IndexQuery
The index returned an application-level account-history error.
Fields
IncompleteCollection
Complete collection stopped before the source API was exhausted.
Fields
CollectionPage
A page fetch failed after collection had begun.
Fields
CollectionIndexMismatch
A custom collection source returned evidence for a different explicit index.
Fields
InvalidCache
A complete cache failed semantic validation.
InvalidRefreshAttempt
A refresh-attempt sidecar failed semantic validation.