pub struct IcrcAccountTransactionPageReport {Show 16 fields
pub schema_version: u32,
pub ledger_canister_id: String,
pub index_canister_id: String,
pub account_owner: String,
pub subaccount_hex: Option<String>,
pub requested_start: Option<String>,
pub requested_limit: u32,
pub next_start: Option<String>,
pub oldest_transaction_id: Option<String>,
pub balance: String,
pub token_symbol: String,
pub decimals: u8,
pub fetched_at: String,
pub source_endpoint: String,
pub fetched_by: String,
pub transactions: Vec<IcrcAccountTransactionRow>,
}Expand description
IcrcAccountTransactionPageReport
Serializable report for a backward page of ICRC index account transactions.
Fields
schema_version: u32Report schema version.
ledger_canister_id: StringLedger canister whose transactions were indexed.
index_canister_id: StringIndex canister that answered the account-history query.
account_owner: StringQueried account owner principal.
subaccount_hex: Option<String>Queried subaccount as normalized hex.
requested_start: Option<String>Exclusive block-index cursor supplied by the caller.
requested_limit: u32Maximum number of transactions requested.
next_start: Option<String>Cursor to pass as start to request the next older page.
oldest_transaction_id: Option<String>Oldest transaction id known for this account.
balance: StringAccount balance reported by the index at its synchronized tip.
token_symbol: StringLedger token symbol used for text rendering.
decimals: u8Ledger token decimals used for text rendering.
fetched_at: StringCollection timestamp in UTC text form.
source_endpoint: StringIC API endpoint used for ledger and index calls.
fetched_by: StringCollector identity.
transactions: Vec<IcrcAccountTransactionRow>Transactions returned by the index in its native page order.