pub struct NnsNeuronDistributionReport {Show 26 fields
pub schema_version: u32,
pub network: String,
pub governance_canister_id: String,
pub source: NnsGovernanceSourceProvenance,
pub collection_started_at: String,
pub collection_updated_at: String,
pub collection_page_count: u32,
pub collected_neuron_count: u64,
pub point_in_time_guaranteed: bool,
pub earliest_retrieved_at_timestamp_seconds: Option<u64>,
pub latest_retrieved_at_timestamp_seconds: Option<u64>,
pub total_effective_stake_e8s: u64,
pub reported_staked_maturity_neuron_count: u64,
pub unreported_staked_maturity_neuron_count: u64,
pub total_reported_staked_maturity_e8s_equivalent: u64,
pub reported_deciding_voting_power_neuron_count: u64,
pub unreported_deciding_voting_power_neuron_count: u64,
pub total_reported_deciding_voting_power: u64,
pub reported_potential_voting_power_neuron_count: u64,
pub unreported_potential_voting_power_neuron_count: u64,
pub total_reported_potential_voting_power: u64,
pub known_neuron_metadata_count: u64,
pub neurons_fund_join_timestamp_present_count: u64,
pub state_distribution: Vec<NnsNeuronStateDistribution>,
pub visibility_distribution: Vec<NnsNeuronVisibilityDistribution>,
pub neuron_type_distribution: Vec<NnsNeuronTypeDistribution>,
}Expand description
NnsNeuronDistributionReport
Deterministic local distribution over one complete public NNS neuron collection.
Fields
schema_version: u32Report schema version.
network: StringNetwork identity retained by the complete collection.
governance_canister_id: StringFixed NNS Governance canister principal retained by the collection.
source: NnsGovernanceSourceProvenanceConcrete transport and collector provenance retained by the collection.
collection_started_at: StringCaller-supplied time attached to collection creation.
collection_updated_at: StringCaller-supplied time attached to the final admitted page.
collection_page_count: u32Number of admitted source pages in the complete collection.
collected_neuron_count: u64Number of admitted public neuron rows in the complete collection.
point_in_time_guaranteed: boolWhether the sequential collection is guaranteed to represent one point in time.
earliest_retrieved_at_timestamp_seconds: Option<u64>Earliest raw Governance retrieval timestamp among collected rows.
latest_retrieved_at_timestamp_seconds: Option<u64>Latest raw Governance retrieval timestamp among collected rows.
total_effective_stake_e8s: u64Sum of public effective stake across every collected neuron.
reported_staked_maturity_neuron_count: u64Rows carrying a public staked-maturity value.
unreported_staked_maturity_neuron_count: u64Rows without a public staked-maturity value.
total_reported_staked_maturity_e8s_equivalent: u64Sum of reported staked maturity values only.
reported_deciding_voting_power_neuron_count: u64Rows carrying current deciding voting power.
unreported_deciding_voting_power_neuron_count: u64Rows without current deciding voting power.
total_reported_deciding_voting_power: u64Sum of reported current deciding voting power values only.
reported_potential_voting_power_neuron_count: u64Rows carrying current potential voting power.
unreported_potential_voting_power_neuron_count: u64Rows without current potential voting power.
total_reported_potential_voting_power: u64Sum of reported current potential voting power values only.
known_neuron_metadata_count: u64Rows carrying registered known-neuron metadata.
neurons_fund_join_timestamp_present_count: u64Rows carrying a public Neurons’ Fund join timestamp.
state_distribution: Vec<NnsNeuronStateDistribution>Canonically raw-code-ordered distribution by neuron state.
visibility_distribution: Vec<NnsNeuronVisibilityDistribution>Canonically optional-raw-code-ordered distribution by visibility.
neuron_type_distribution: Vec<NnsNeuronTypeDistribution>Canonically optional-raw-code-ordered distribution by neuron type.