NnsNeuronInfoReport

Struct NnsNeuronInfoReport 

pub struct NnsNeuronInfoReport {
    pub schema_version: u32,
    pub network: String,
    pub governance_canister_id: String,
    pub fetched_at: String,
    pub source_endpoint: String,
    pub fetched_by: String,
    pub cache_path: Option<String>,
    pub from_cache: bool,
    pub verbose: bool,
    pub neuron: NnsNeuronRow,
}
NnsNeuronInfoReport

Serializable public view of one NNS neuron.

Fields

schema_version: u32

Report schema version.

network: String

Queried network identity.

governance_canister_id: String

NNS Governance canister principal.

fetched_at: String

UTC collection timestamp.

source_endpoint: String

Replica endpoint or cached snapshot endpoint provenance.

fetched_by: String

Collector identity.

cache_path: Option<String>

Cache path when the row came from a complete snapshot.

from_cache: bool

Whether the row came from a complete local snapshot.

verbose: bool

Whether verbose text rendering was requested.

neuron: NnsNeuronRow

Public Governance neuron view.