pub struct NnsNeuronInfoReport {
pub schema_version: u32,
pub network: String,
pub governance_canister_id: String,
pub fetched_at: String,
pub source_endpoint: String,
pub fetched_by: String,
pub cache_path: Option<String>,
pub from_cache: bool,
pub verbose: bool,
pub neuron: NnsNeuronRow,
}Expand description
NnsNeuronInfoReport
Serializable public view of one NNS neuron.
Fields
schema_version: u32Report schema version.
network: StringQueried network identity.
governance_canister_id: StringNNS Governance canister principal.
fetched_at: StringUTC collection timestamp.
source_endpoint: StringReplica endpoint or cached snapshot endpoint provenance.
fetched_by: StringCollector identity.
cache_path: Option<String>Cache path when the row came from a complete snapshot.
from_cache: boolWhether the row came from a complete local snapshot.
verbose: boolWhether verbose text rendering was requested.
neuron: NnsNeuronRowPublic Governance neuron view.