NnsProposalError

Enum NnsProposalError 

pub enum NnsProposalError {
    Governance(NnsGovernanceError),
    InvalidLimit {
        limit: u32,
        maximum: u32,
    },
    PageTooLarge {
        actual: usize,
        requested: u32,
    },
    MissingProposalIdInPage,
    DuplicateProposalId {
        proposal_id: u64,
    },
    ProposalCursorMismatch {
        proposal_id: u64,
        before_proposal_id: u64,
    },
    ProposalNotFound {
        proposal_id: u64,
    },
    ProposalIdMismatch {
        expected: u64,
        actual: Option<u64>,
    },
}
NnsProposalError

Portable failure returned while collecting or assembling proposal reports.

Variants



Governance(NnsGovernanceError)

Shared Governance request, transport, or provenance validation failed.



InvalidLimit

The requested page size is outside the bounded proposal contract.

Fields

limit: u32
maximum: u32


PageTooLarge

Governance returned more proposal rows than requested.

Fields

actual: usize
requested: u32


MissingProposalIdInPage

A proposal page row did not include its required identifier.



DuplicateProposalId

A proposal page repeated an identifier.

Fields

proposal_id: u64


ProposalCursorMismatch

A proposal did not satisfy the exclusive page cursor.

Fields

proposal_id: u64
before_proposal_id: u64


ProposalNotFound

Governance did not return the requested proposal.

Fields

proposal_id: u64


ProposalIdMismatch

Governance returned a different proposal than requested.

Fields

expected: u64
actual: Option<u64>