pub struct SnsTokenStandardRow {
pub name: String,
pub url: String,
}Expand description
SnsTokenStandardRow
Serializable row for one token standard supported by an SNS ledger.
Fields
name: Stringurl: StringTrait Implementations
Sourceimpl Clone for SnsTokenStandardRow
impl Clone for SnsTokenStandardRow
Sourcefn clone(&self) -> SnsTokenStandardRow
fn clone(&self) -> SnsTokenStandardRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnsTokenStandardRow
impl Debug for SnsTokenStandardRow
impl Eq for SnsTokenStandardRow
Sourceimpl PartialEq for SnsTokenStandardRow
impl PartialEq for SnsTokenStandardRow
Sourcefn eq(&self, other: &SnsTokenStandardRow) -> bool
fn eq(&self, other: &SnsTokenStandardRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SnsTokenStandardRow
impl Serialize for SnsTokenStandardRow
impl StructuralPartialEq for SnsTokenStandardRow