CatalogError

Enum CatalogError 

pub enum CatalogError {
Show 31 variants Json(Error), UnsupportedSchemaVersion { found: u32, supported: u32, }, NetworkMismatch { expected: String, actual: String, }, RegistryCanisterMismatch { expected: String, actual: String, }, InvalidRegistryVersion, EmptySubnets, EmptyRoutingRanges, InvalidPrincipal { field: &'static str, value: String, reason: String, }, DuplicateSubnet { subnet_principal: String, }, NonCanonicalSubnetOrder { previous: String, current: String, }, UnknownRoutingSubnet { subnet_principal: String, }, InvalidRoutingRange { subnet_principal: String, start_canister_id: String, end_canister_id: String, }, OverlappingRoutingRanges { first: Box<RoutingRange>, second: Box<RoutingRange>, }, NonCanonicalRoutingOrder { previous: Box<RoutingRange>, current: Box<RoutingRange>, }, SubnetKindMismatch { subnet_principal: String, registry_subnet_type: i32, expected: String, actual: String, }, ChargingPolicyMismatch { subnet_principal: String, expected: bool, actual: bool, }, ClassificationMismatch { subnet_principal: String, field: &'static str, reason: String, }, InvalidTimestamp { field: &'static str, value: String, }, FutureTimestamp { field: &'static str, value: String, latest_allowed_unix_secs: u64, }, InvalidSourceEndpoint { endpoint: String, reason: String, }, InvalidProvenance { field: &'static str, reason: String, }, UnsupportedAssurance { assurance: String, }, ClassificationPolicyVersionMismatch { found: u32, supported: u32, }, ClassificationPolicyDigestMismatch { expected: String, actual: String, }, ResolverPolicyMismatch { expected_version: u32, actual_version: u32, expected_backend: String, actual_backend: String, }, InvalidCatalogDigest { value: String, }, CatalogDigestMismatch { expected: String, actual: String, }, UnknownSubnet { subnet_principal: String, }, PrincipalPrefixNotFound { prefix: String, }, AmbiguousPrincipalPrefix { prefix: String, matches: Vec<String>, }, RouteNotFound { canister_principal: String, registry_version: u64, catalog_schema_version: u32, },
}
CatalogError

Errors returned while parsing, validating, or resolving a subnet catalog.

Variants



Json(Error)



UnsupportedSchemaVersion

Fields

found: u32
supported: u32


NetworkMismatch

Catalog network identity does not match the required authority.

Fields

expected: String

Required network identity.

actual: String

Catalog network identity.



RegistryCanisterMismatch

Catalog Registry canister identity does not match mainnet authority.

Fields

expected: String

Required Registry canister principal.

actual: String

Catalog Registry canister principal.



InvalidRegistryVersion

Registry version zero cannot identify an authority snapshot.



EmptySubnets



EmptyRoutingRanges



InvalidPrincipal

Fields

field: &'static str
value: String
reason: String


DuplicateSubnet

Fields

subnet_principal: String


NonCanonicalSubnetOrder

Subnet rows are not strictly ordered by canonical principal text.

Fields

previous: String

Previous Subnet principal.

current: String

Current Subnet principal.



UnknownRoutingSubnet

Fields

subnet_principal: String


InvalidRoutingRange

Fields

subnet_principal: String
start_canister_id: String
end_canister_id: String


OverlappingRoutingRanges

Fields



NonCanonicalRoutingOrder

Routing ranges are not strictly ordered by principal bytes and target.

Fields

previous: Box<RoutingRange>

Previous routing range.

current: Box<RoutingRange>

Current routing range.



SubnetKindMismatch

Derived Subnet kind contradicts its raw Registry numeric code.

Fields

subnet_principal: String

Subnet principal.

registry_subnet_type: i32

Raw Registry numeric discriminant.

expected: String

Kind required by the raw discriminant.

actual: String

Kind supplied by the raw catalog.



ChargingPolicyMismatch

Charging default contradicts the raw Registry Subnet kind.

Fields

subnet_principal: String

Subnet principal.

expected: bool

Charging default required by the raw kind.

actual: bool

Charging default supplied by the raw catalog.



ClassificationMismatch

Classification metadata contradicts its policy or source.

Fields

subnet_principal: String

Subnet principal.

field: &'static str

Invalid classification field.

reason: String

Deterministic mismatch reason.



InvalidTimestamp

A provenance timestamp is not valid canonical UTC text.

Fields

field: &'static str

Timestamp field.

value: String

Invalid timestamp text.



FutureTimestamp

A provenance timestamp is beyond the caller’s future-skew policy.

Fields

field: &'static str

Timestamp field.

value: String

Future timestamp text.

latest_allowed_unix_secs: u64

Latest accepted Unix time.



InvalidSourceEndpoint

A source endpoint is not a clean credential-free HTTP(S) base URL.

Fields

endpoint: String

Invalid endpoint.

reason: String

Endpoint validation reason.



InvalidProvenance

Provenance evidence is internally inconsistent.

Fields

field: &'static str

Invalid provenance field.

reason: String

Deterministic validation reason.



UnsupportedAssurance

The build does not yet have a verifier for the claimed assurance level.

Fields

assurance: String

Unsupported assurance label.



ClassificationPolicyVersionMismatch

Classification policy schema is not supported by this build.

Fields

found: u32

Catalog policy schema.

supported: u32

Supported policy schema.



ClassificationPolicyDigestMismatch

Classification policy digest does not match this build.

Fields

expected: String

Expected policy digest.

actual: String

Catalog policy digest.



ResolverPolicyMismatch

Resolver implementation identity does not match this build.

Fields

expected_version: u32

Expected resolver schema.

actual_version: u32

Catalog resolver schema.

expected_backend: String

Expected resolver backend.

actual_backend: String

Catalog resolver backend.



InvalidCatalogDigest

Catalog digest is not exactly 32 lowercase hexadecimal bytes.

Fields

value: String

Invalid digest text.



CatalogDigestMismatch

Stored catalog digest does not match the canonical authority payload.

Fields

expected: String

Recomputed digest.

actual: String

Stored digest.



UnknownSubnet

Fields

subnet_principal: String


PrincipalPrefixNotFound

Fields

prefix: String


AmbiguousPrincipalPrefix

Fields

prefix: String
matches: Vec<String>


RouteNotFound

Fields

canister_principal: String
registry_version: u64
catalog_schema_version: u32